"""Main entry point for ToDoWrite-cli package."""

from .main import main

if __name__ == "__main__":
    main()
